@@ -200,3 +200,15 @@ def sample_patch_tgz_no_series(tmp_path, sample_patch, sample_patch_dir):
     with tarfile.open(tar_file, "w:gz") as tar:
         tar.add(tmp_path, arcname=os.path.sep)
     return str(tar_file)
+
+
+@pytest.fixture
+def sample_manifest():
+    return '<?xml version="1.0" encoding="UTF-8"?><manifest></manifest>'
+
+
+@pytest.fixture
+def sample_manifest_file(tmp_path, sample_manifest):
+    m = tmp_path / "default.xml"
+    m.write_text(sample_manifest)
+    return str(m)
