@@ -207,8 +207,9 @@ class TestBitbake:
             "local_conf": [],
             "bblayers_conf": [],
             "container": bitbake.build_definition.container,
+            "manifest": None,
         }
-        assert bitbake.generate_build_request() == expected_data
+        assert bitbake.generate_build_request() == (expected_data, {})
 
     def test_submit_build(self, bitbake, bitbake_attrs, mocker):
         post_request = mocker.patch("tuxsuite.build.post_request")
@@ -236,9 +237,28 @@ class TestBitbake:
                 "local_conf": [],
                 "bblayers_conf": [],
                 "container": bitbake.build_definition.container,
+                "manifests": {},
             },
         )
 
+    def test_handle_manifest(self, mocker, sample_manifest, sample_manifest_file):
+        guess = mocker.patch(
+            "mimetypes.guess_type", return_value=("application/xml", None)
+        )
+        result = tuxsuite.build.handle_manifest(sample_manifest_file)
+        assert guess.call_count == 1
+        assert isinstance(result, type(()))
+        assert isinstance(type(result[0]), type(str))
+        assert base64.b64decode(result[1]) == sample_manifest.encode("utf-8")
+
+    def test_handle_manifest_url(self):
+        url = "https://test.example.com/url"
+        result = tuxsuite.build.handle_manifest(url)
+        assert isinstance(result, type(()))
+        assert isinstance(type(result[0]), type(str))
+        assert result[0] == url
+        assert base64.b64decode(result[1]) == b""
+
 
 class TestBitbakeWatch(TestWatch):
     @pytest.fixture(autouse=True)
