@@ -20,6 +20,79 @@ def test_usage():
     assert "Commands" in result.output
 
 
+def test_bake_no_args():
+    """Test calling bake() with no options"""
+    runner = CliRunner()
+    result = runner.invoke(tuxsuite.cli.bake, [])
+    assert result.exit_code == 0
+    assert "Usage" in result.output
+    assert "help" in result.output
+
+
+def test_bake_usage():
+    """Test calling bake() with --help"""
+    runner = CliRunner()
+    result = runner.invoke(tuxsuite.cli.bake, ["--help"])
+    assert result.exit_code == 0
+    assert "Usage" in result.output
+    assert "tuxsuite bake submit" in result.output
+
+
+@pytest.fixture
+def sample_bitbake_template():
+    return """
+{
+  "container": "ubuntu-20.04",
+  "envsetup": "poky/oe-init-build-env",
+  "distro": "poky",
+  "machine": "qemux86-64",
+  "target": "core-image-minimal",
+  "sources": {
+    "git_trees": [
+      {
+        "url": "git://git.yoctoproject.org/poky",
+        "branch": "dunfell"
+      }
+    ]
+  }
+}
+"""
+
+
+def test_bake(mocker, tmp_path, tuxsuite_config, sample_bitbake_template):
+    template = tmp_path / "yocto.json"
+    template.write_text(sample_bitbake_template)
+    build = mocker.patch("tuxsuite.Bitbake.build")
+    wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxsuite.cli.bake,
+        [
+            "submit",
+            f"{template}",
+        ],
+    )
+    assert result.exit_code == 0
+    assert build.call_count == 1
+    assert wait_for_object.call_count == 1
+
+
+def test_bake_invalid_json(mocker, tmp_path, tuxsuite_config, sample_bitbake_template):
+    template = tmp_path / "yocto.json"
+    template.write_text("random text")
+    mocker.patch("tuxsuite.Bitbake.build")
+    mocker.patch("tuxsuite.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxsuite.cli.bake,
+        [
+            "submit",
+            f"{template}",
+        ],
+    )
+    assert result.exit_code == 1
+
+
 def test_build_no_args():
     """Test calling build() with no options"""
     runner = CliRunner()
@@ -318,8 +391,68 @@ def plan_config(tmp_path, tuxauth):
     return config
 
 
+@pytest.fixture
+def plan_builds():
+    build_attrs = {
+        "group": "tuxgrp",
+        "project": "tuxprj",
+        "git_repo": "http://github.com/torvalds/linux",
+        "git_ref": "master",
+        "target_arch": "arm",
+        "kconfig": "defconfig",
+        "build_name": "test_build_name",
+        "toolchain": "gcc-9",
+        "token": "test_token",
+        "kbapi_url": "http://test/foo",
+        "tuxapi_url": "http://tuxapi",
+        "kernel_image": "Image",
+    }
+    builds = [
+        tuxsuite.build.Build(**build_attrs, uid="build-1"),
+        tuxsuite.build.Build(**build_attrs, uid="build-2"),
+        tuxsuite.build.Build(**build_attrs, uid="build-3"),
+        tuxsuite.build.Build(**build_attrs, uid="build-4"),
+        tuxsuite.build.Build(**build_attrs, uid="build-5"),
+        tuxsuite.build.Build(**build_attrs, uid="build-6"),
+        tuxsuite.build.Build(**build_attrs, uid="build-7"),
+        tuxsuite.build.Build(**build_attrs, uid="build-8"),
+        tuxsuite.build.Build(**build_attrs, uid="build-9"),
+    ]
+    return builds
+
+
+@pytest.fixture
+def plan_builds_status_list():
+    build_attrs = {
+        "group": "tuxgrp",
+        "project": "tuxprj",
+        "git_repo": "http://github.com/torvalds/linux",
+        "git_ref": "master",
+        "target_arch": "arm",
+        "kconfig": "defconfig",
+        "build_name": "test_build_name",
+        "toolchain": "gcc-9",
+        "token": "test_token",
+        "kbapi_url": "http://test/foo",
+        "tuxapi_url": "http://tuxapi",
+        "kernel_image": "Image",
+    }
+    builds = [
+        build_attrs,
+        build_attrs,
+        build_attrs,
+        build_attrs,
+        build_attrs,
+        build_attrs,
+        build_attrs,
+        build_attrs,
+        build_attrs,
+    ]
+    return builds
+
+
 def test_build_set(mocker, tuxsuite_config, tux_config):
-    build = mocker.patch("tuxsuite.BuildSet.build")
+    build = mocker.patch("tuxsuite.Plan.submit")
     wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
     runner = CliRunner()
     result = runner.invoke(
@@ -336,28 +469,8 @@ def test_build_set(mocker, tuxsuite_config, tux_config):
     assert wait_for_object.call_count == 1
 
 
-def test_build_set_no_kconfig(mocker, tuxsuite_config, tux_config):
-    build = mocker.patch("tuxsuite.BuildSet.build")
-    wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
-    runner = CliRunner()
-    result = runner.invoke(
-        tuxsuite.cli.build_set,
-        [
-            "--git-repo=https://git.example.com/linux.git",
-            "--git-ref=master",
-            f"--tux-config={tux_config}",
-            "--set-name=arch-matrix",
-            "--quiet",
-        ],
-    )
-    build.assert_not_called()
-    wait_for_object.assert_not_called()
-    assert result.exit_code == 1
-    assert "kconfig is mandatory" in result.output
-
-
 def test_build_set_quiet(mocker, tuxsuite_config, tux_config):
-    BuildSet = mocker.patch("tuxsuite.BuildSet")
+    BuildSet = mocker.patch("tuxsuite.Plan")
     builds = []
     for i in range(1, 10):
         build = mocker.MagicMock()
@@ -382,7 +495,7 @@ def test_build_set_quiet(mocker, tuxsuite_config, tux_config):
 
 
 def test_build_set_git_sha(mocker, tuxsuite_config, tux_config):
-    build = mocker.patch("tuxsuite.BuildSet.build")
+    build = mocker.patch("tuxsuite.Plan.submit")
     wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
     runner = CliRunner()
     result = runner.invoke(
@@ -400,8 +513,9 @@ def test_build_set_git_sha(mocker, tuxsuite_config, tux_config):
     assert wait_for_object.call_count == 1
 
 
-def test_build_set_download(mocker, tuxsuite_config, tux_config):
-    build = mocker.patch("tuxsuite.BuildSet.build")
+def test_build_set_download(mocker, tuxsuite_config, tux_config, plan_builds):
+    build = mocker.patch("tuxsuite.Plan")
+    build.return_value.builds = plan_builds
     wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
     download = mocker.patch("tuxsuite.download.download")
     runner = CliRunner()
@@ -421,8 +535,9 @@ def test_build_set_download(mocker, tuxsuite_config, tux_config):
     assert download.call_count == 9
 
 
-def test_build_set_show_logs(mocker, tuxsuite_config, tux_config):
-    build = mocker.patch("tuxsuite.BuildSet.build")
+def test_build_set_show_logs(mocker, tuxsuite_config, tux_config, plan_builds):
+    build = mocker.patch("tuxsuite.Plan")
+    build.return_value.builds = plan_builds
     wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
     show_log = mocker.patch("tuxsuite.cli.show_log")
     runner = CliRunner()
@@ -718,6 +833,7 @@ def test_plan_cli_options(mocker, plan_config, tuxsuite_config):
     assert download.call_count == 2
     assert show_log.call_count == 2
 
+    print(result)
     assert (
         """Running Linux Kernel plan 'Simple plan': 'A simple plan'
 Plan http://api/v1/groups/grp/projects/prj/plans/1sMUTVjE25tQvDmjJ8SjWblpOJr
@@ -942,8 +1058,12 @@ def test_build_no_wait(mocker, tmp_path):
     assert format_result.call_count == 1
 
 
-def test_build_set_no_wait(mocker, tuxsuite_config, tux_config, tmp_path):
-    build = mocker.patch("tuxsuite.BuildSet.build")
+def test_build_set_no_wait(
+    mocker, tuxsuite_config, tux_config, tmp_path, plan_builds, plan_builds_status_list
+):
+    build = mocker.patch("tuxsuite.Plan")
+    build.return_value.builds = plan_builds
+    build.return_value.build_status_list = plan_builds_status_list
     format_result = mocker.patch("tuxsuite.cli.format_result")
     runner = CliRunner()
     result = runner.invoke(
@@ -957,6 +1077,7 @@ def test_build_set_no_wait(mocker, tuxsuite_config, tux_config, tmp_path):
             f"--json-out={tmp_path}/build_result.json",
         ],
     )
+
     assert result.exit_code == 0
     assert build.call_count == 1
     assert format_result.call_count == 9
@@ -1439,3 +1560,20 @@ def test_build_config(mocker, tuxsuite_config):
         ],
     )
     assert result.exit_code == 2
+
+
+def test_build_set_empty_config(mocker, tuxsuite_config, tux_config):
+    plan_config = mocker.patch("tuxsuite.config.BuildSetConfig")
+    plan_config.return_value.plan = None
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxsuite.cli.build_set,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-ref=master",
+            f"--tux-config={tux_config}",
+            "--set-name=test",
+        ],
+    )
+    assert result.exit_code == 0
+    assert "Empty plan, skipping" in result.output
