@@ -103,6 +103,28 @@ def handle_patch(patch_path):
     return (patch_file, patch_content.decode("utf-8"))
 
 
+def handle_manifest(manifest_path):
+    manifest_is_web_url = False
+    manifest_content = None
+    manifest_file = os.path.basename(manifest_path)
+    if urlparse(manifest_path).scheme in ["http", "https"]:
+        manifest_file = manifest_path
+        manifest_content = b""
+        manifest_is_web_url = True
+    else:
+        if os.path.isfile(manifest_path):
+            file_type, file_encoding = mimetypes.guess_type(manifest_path)
+            if file_type not in ["application/xml", "text/xml"]:
+                raise Exception("Manifest format unknown")
+            with open(manifest_path, "rb") as manifest:
+                manifest_content = base64.b64encode(manifest.read())
+
+    if not manifest_is_web_url:
+        manifest_sha256 = hashlib.sha256(manifest_content).hexdigest()
+        manifest_file = f"{manifest_sha256}/{manifest_file}"
+    return (manifest_file, manifest_content.decode("utf-8"))
+
+
 class HeadersMixin:
     @property
     def headers(self):
@@ -696,7 +718,7 @@ class Plan(HeadersMixin):
             nr_tests = len(self.results["tests"])
             if nr_builds == n_builds and nr_tests == n_tests:
                 break
-            time.sleep(5)
+            time.sleep(random.randrange(delay_status_update))
 
     def wait(self):
         states = []
@@ -937,6 +959,7 @@ class Bitbake(HeadersMixin):
     data = attrib(default={})
     build_definition = attrib(default={})
     build_data = attrib(default=None)
+    manifest = attrib(default=None)
 
     @attrs(kw_only=True, order=False)
     class BuildDefinition:
@@ -950,6 +973,7 @@ class Bitbake(HeadersMixin):
         local_conf = attrib(default=[])
         bblayers_conf = attrib(default=[])
         container = attrib(default="ubuntu-20.04")
+        manifest = attrib(default=None)
 
     def __attrs_post_init__(self):
         self.build_definition = self.BuildDefinition(**(self.data))
@@ -965,11 +989,20 @@ class Bitbake(HeadersMixin):
 
     def generate_build_request(self, plan=None):
         """return a build data in a python dict"""
-        return self.build_definition.__dict__
+        manifests = {}
+        build_data = self.build_definition.__dict__
+        if self.build_definition.manifest:
+            (build_data["manifest_file"], manifest) = handle_manifest(
+                self.build_definition.manifest
+            )
+            manifests[build_data["manifest_file"]] = manifest
+        return (build_data, manifests)
 
     def build(self, plan=None):
         """Submit the build request"""
-        data = self.generate_build_request(plan=plan)
+        data, manifest = self.generate_build_request(plan=plan)
+        data["manifests"] = manifest
+        del data["manifest"]
         url = self.tuxapi_url + "/v1/groups/{}/projects/{}/oebuilds".format(
             self.group, self.project
         )
