@@ -528,7 +528,18 @@ def bake():
     help="Write json build status out to a named file path",
     type=click.File("w", encoding="utf-8"),
 )
-def submit(build_definition, json_out=None):
+@click.option(
+    "-l",
+    "--local-manifest",
+    type=file_or_url,
+    default=None,
+    help=(
+        "Path to a local manifest file which will be used during repo sync."
+        "This input is ignored if sources used is git_trees in the build"
+        "definition. Should be a valid XML"
+    ),
+)
+def submit(build_definition, json_out=None, local_manifest=None):
     try:
         with open(os.path.abspath(build_definition)) as reader:
             data = json_lib.load(reader)
@@ -537,6 +548,8 @@ def submit(build_definition, json_out=None):
             f"Problem parsing {build_definition}, Is it a valid json file ?\n"
         )
         sys.exit(1)
+    if local_manifest:
+        data["manifest"] = click.format_filename(local_manifest)
     try:
         build = tuxsuite.Bitbake(data=data)
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
@@ -778,6 +791,7 @@ TESTS = [
     "libpdfium",
     "libpng",
     "logd",
+    "purecap",
     "multicore",
     "ltp-fcntl-locktests",
     "ltp-fs_bind",
@@ -1162,6 +1176,9 @@ def plan(
 
     try:
         plan_config = tuxsuite.config.PlanConfig(name, description, config, job_name)
+        if plan_config.schema_warning:
+            warning(f"Invalid plan file: {plan_config.schema_warning}")
+
         if not plan_config.plan:
             warning("Empty plan, skipping")
             return
